@@ -10,6 +10,7 @@ extern crate proc_macro;
 use proc_macro::TokenStream;
 
 mod entrypoint;
+mod persist;
 
 // Declarations ==============================================================
 #[proc_macro_attribute]
@@ -18,21 +19,11 @@ pub fn main(args: TokenStream, item: TokenStream) -> TokenStream {
   entrypoint::generate_main(args,item)
 }
 
+#[proc_macro_derive(Persist, attributes(persist))]
+pub fn derive_persist(item: TokenStream) -> TokenStream {
+  persist::derive_persist(item)
+}
 // Code ======================================================================
 
 
 // Tests =====================================================================
-#[cfg(test)]
-mod tests {
-  #[allow(unused_imports)]
-  use super::*;
-
-  #[test]
-  fn a_test() {}
-
-  #[test]
-  #[should_panic]
-  fn a_failure_test() {
-    panic!()
-  }
-}
\ No newline at end of file
